@@ -8,11 +8,13 @@
 #define SILENT
 #endif
 
+
 #include <new>
 #include <string>
 #include <vector>
+#include <deque>
 #include <memory> // For automatic pointers.
-
+#include <algorithm>
 
 #ifdef _WIN_ALL
 
@@ -56,6 +58,9 @@
 #include <wincrypt.h>
 #include <wchar.h>
 #include <wctype.h>
+#include <Sddl.h>
+#include <ntsecapi.h>
+
 
 // For WMI requests.
 #include <comdef.h>
@@ -132,6 +137,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <stddef.h> // Needed for ptrdiff_t in some UnRAR source builds.
 #include <string.h>
 #include <ctype.h>
 #include <fcntl.h>
@@ -211,6 +217,10 @@
   #endif
 #endif
 
+#ifdef __VMS
+# define LITTLE_ENDIAN
+#endif
+
 // Unlike Apple x64, utimensat shall be available in all Apple M1 systems.
 #if _POSIX_C_SOURCE >= 200809L || defined(__APPLE__) && defined(__arm64__)
   #define UNIX_TIME_NS // Nanosecond time precision in Unix.
