@@ -8,16 +8,14 @@ class SecPassword
   private:
     void Process(const wchar *Src,size_t SrcSize,wchar *Dst,size_t DstSize,bool Encode);
 
-    wchar Password[MAXPASSWORD];
-
-    // It is important to have this 'bool' value, so if our object is cleaned
-    // with memset as a part of larger structure, it is handled correctly.
+    std::vector<wchar> Password = std::vector<wchar>(MAXPASSWORD);
     bool PasswordSet;
   public:
     SecPassword();
     ~SecPassword();
     void Clean();
     void Get(wchar *Psw,size_t MaxSize);
+    void Get(std::wstring &Psw);
     void Set(const wchar *Psw);
     bool IsSet() {return PasswordSet;}
     size_t Length();
@@ -26,6 +24,7 @@ class SecPassword
 
 
 void cleandata(void *data,size_t size);
-void SecHideData(void *Data,size_t DataSize,bool Encode);
+inline void cleandata(std::wstring &s) {cleandata(&s[0],s.size()*sizeof(s[0]));}
+void SecHideData(void *Data,size_t DataSize,bool Encode,bool CrossProcess);
 
 #endif
